@@ -2,7 +2,7 @@
 
 /* 
  * constants defined for LDAP
- * $Id: constants.c,v 1.25 2005/11/17 20:49:28 stroeder Exp $
+ * $Id: constants.c,v 1.28 2007/03/22 22:06:06 stroeder Exp $
  */
 
 #include "common.h"
@@ -144,6 +144,7 @@ LDAPinit_constants( PyObject* d )
 #ifdef LDAP_OPT_REFERRALS
 	add_int(d,OPT_REFERRALS);
 #endif
+	add_int(d,OPT_ERROR_NUMBER);
 	add_int(d,OPT_RESTART);
 	add_int(d,OPT_PROTOCOL_VERSION);
 	add_int(d,OPT_SERVER_CONTROLS);
@@ -173,6 +174,11 @@ LDAPinit_constants( PyObject* d )
 	add_int(d,OPT_X_TLS_DEMAND);
 	add_int(d,OPT_X_TLS_ALLOW);
 	add_int(d,OPT_X_TLS_TRY);
+        /* only available if OpenSSL supports it => might cause backward compability problems */
+	add_int(d,OPT_X_TLS_CRLCHECK);
+	add_int(d,OPT_X_TLS_CRL_NONE);
+	add_int(d,OPT_X_TLS_CRL_PEER);
+	add_int(d,OPT_X_TLS_CRL_ALL);
 #endif
 	add_int(d,OPT_X_SASL_MECH);
 	add_int(d,OPT_X_SASL_REALM);
@@ -183,6 +189,25 @@ LDAPinit_constants( PyObject* d )
 	add_int(d,OPT_X_SASL_SECPROPS);
 	add_int(d,OPT_X_SASL_SSF_MIN);
 	add_int(d,OPT_X_SASL_SSF_MAX);
+
+	add_int(d,DN_FORMAT_LDAP);
+	add_int(d,DN_FORMAT_LDAPV3);
+	add_int(d,DN_FORMAT_LDAPV2);
+	add_int(d,DN_FORMAT_DCE);
+	add_int(d,DN_FORMAT_UFN);
+	add_int(d,DN_FORMAT_AD_CANONICAL);
+	/* add_int(d,DN_FORMAT_LBER); */    /* "for testing only" */
+	add_int(d,DN_FORMAT_MASK);
+	add_int(d,DN_PRETTY);
+	add_int(d,DN_SKIP);
+	add_int(d,DN_P_NOLEADTRAILSPACES);
+	add_int(d,DN_P_NOSPACEAFTERRDN);
+	add_int(d,DN_PEDANTIC);
+
+	add_int(d,AVA_NULL);
+	add_int(d,AVA_STRING);
+	add_int(d,AVA_BINARY);
+	add_int(d,AVA_NONPRINTABLE);
 	
 	/*add_int(d,OPT_ON);*/
 	obj = PyInt_FromLong(1);
@@ -202,7 +227,7 @@ LDAPinit_constants( PyObject* d )
 
 	/* author */
 
-	author = PyString_FromString("David Leonard <leonard@it.uq.edu.au>");
+	author = PyString_FromString("python-ldap-dev@lists.sf.net");
 	PyDict_SetItemString(d, "__author__", author);
 	Py_DECREF(author);
 
