@@ -4,7 +4,7 @@
 
 /*
  * ldapcontrol.c - wrapper around libldap LDAPControl structs.
- * $Id: ldapcontrol.c,v 1.5 2006/04/10 05:19:46 stroeder Exp $
+ * $Id: ldapcontrol.c,v 1.7 2006/12/06 07:36:00 stroeder Exp $
  */
 
 #include "common.h"
@@ -75,7 +75,7 @@ Tuple_to_LDAPControl( PyObject* tup )
     struct berval berbytes;
     PyObject *bytes;
     LDAPControl *lc = NULL;
-    int len;
+    Py_ssize_t len;
 
     if (!PyTuple_Check(tup)) {
 	PyErr_SetObject(PyExc_TypeError, Py_BuildValue("sO",
@@ -130,7 +130,7 @@ Tuple_to_LDAPControl( PyObject* tup )
 LDAPControl**
 List_to_LDAPControls( PyObject* list )
 {
-    int len, i;
+    Py_ssize_t len, i;
     LDAPControl** ldcs;
     LDAPControl* ldc;
     PyObject* item;
@@ -173,7 +173,7 @@ LDAPControls_to_List(LDAPControl **ldcs)
 {
     PyObject *res = 0, *pyctrl;
     LDAPControl **tmp = ldcs;
-    unsigned num_ctrls = 0, i;
+    Py_ssize_t num_ctrls = 0, i;
 
     if (tmp)
         while (*tmp++) num_ctrls++;
